@@ -32,7 +32,7 @@ import javax.management.MalformedObjectNameException;
  * @author roland
  * @since Aug 7, 2009
  */
-public class AttributeChecking implements AttributeCheckingMBean,MBeanRegistration {
+public class AttributeChecking implements AttributeCheckingMBean {
 
 
     private boolean state = false;
@@ -75,17 +75,4 @@ public class AttributeChecking implements AttributeCheckingMBean,MBeanRegistrati
         // 10 ms
         return  1f/60 * 0.01;
     }
-
-    public ObjectName preRegister(MBeanServer server, ObjectName name) throws Exception {
-        return new ObjectName("jmx4perl.it:type=attribute");
-    }
-
-    public void postRegister(Boolean registrationDone) {
-    }
-
-    public void preDeregister() throws Exception {
-    }
-
-    public void postDeregister() {
-    }
 }
