@@ -21,7 +21,7 @@ import java.util.regex.Pattern;
 final class JmxRequestFactory {
 
     // Pattern for detecting escaped slashes in URL encoded requests
-    private static final Pattern SLASH_ESCAPE_PATTERN = Pattern.compile("^\\^?-*\\+?$");
+    private static final Pattern SLASH_ESCAPE_PATTERN = Pattern.compile("^-*\\+?$");
 
     // private constructor for static class
     private JmxRequestFactory() { }
@@ -181,17 +181,12 @@ final class JmxRequestFactory {
                 return;
             }
             StringBuffer val;
-
-            // Special escape at the beginning indicates that the this element belongs
-            // to the next one
-            if (element.substring(0,1).equals("^")) {
-                val = new StringBuffer();
-            } else if (previousBuffer == null) {
+            if (previousBuffer == null) {
                 val = new StringBuffer(ret.pop());
             } else {
                 val = previousBuffer;
             }
-            // Append approp. nr of slashes
+            // Decode to value
             for (int j=0;j<element.length();j++) {
                 val.append("/");
             }
